@@ -53,7 +53,6 @@ import org.guvnor.common.services.project.categories.Decision;
 import org.guvnor.common.services.project.model.ProjectImports;
 import org.guvnor.common.services.shared.config.AppConfigService;
 import org.guvnor.common.services.shared.metadata.MetadataService;
-import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.junit.Before;
 import org.junit.BeforeClass;
 import org.junit.Test;
@@ -245,7 +244,7 @@ public class DecisionTableXLSToDecisionTableGuidedConverterTest {
         verify(importsService,
                times(1)).save(projectImportsPathArgumentCaptor.capture(),
                               projectImportsArgumentCaptor.capture(),
-                              any(Metadata.class),
+                              any(),
                               any(String.class));
         assertNotNull(projectImportsPathArgumentCaptor.getValue());
         final Path actualProjectImportsPath = projectImportsPathArgumentCaptor.getValue();
@@ -409,11 +408,11 @@ public class DecisionTableXLSToDecisionTableGuidedConverterTest {
                                        final String cell2Value,
                                        final String cell4Value,
                                        final String cell5Value) {
-        assertEquals(7, rowData.size());
-        assertEquals(cell1Value, rowData.get(3).getStringValue());
-        assertEquals(cell2Value, rowData.get(4).getStringValue());
-        assertEquals(cell4Value, rowData.get(5).getStringValue());
-        assertEquals(cell5Value, rowData.get(6).getStringValue());
+        assertEquals(8, rowData.size());
+        assertEquals(cell1Value, rowData.get(4).getStringValue());
+        assertEquals(cell2Value, rowData.get(5).getStringValue());
+        assertEquals(cell4Value, rowData.get(6).getStringValue());
+        assertEquals(cell5Value, rowData.get(7).getStringValue());
     }
 
     @Test(expected = DecisionTableParseException.class)
